//
//  AppDelegate.m
//  SpeakEasy
//
//  Created by Holger Hinzberg on 14.02.12.
//  Copyright (c) 2012 Cocoa-Coding. All rights reserved.
//

#import "AppDelegate.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize inputText = _inputText;
@synthesize speakButton = _speakButton;
@synthesize stopButton = _stopButton;
@synthesize voicesPopUpButton = _voicesPopUpButton;

- (void)applicationDidFinishLaunching:
  (NSNotification *)aNotification
{
    // Den Sprachsynthesizer instanziieren
    speechSynth = [NSSpeechSynthesizer new];
    speechSynth.delegate = self; 
    
    _stopButton.enabled = NO;
    _speakButton.enabled = YES;
    
    // Alle eventuell vorhandenen Einträge löschen
    [_voicesPopUpButton removeAllItems];
    
    NSArray *voices =
    [NSSpeechSynthesizer availableVoices];

    for (int i = 0; i < [voices count] ; i++)
    {
        // Immer ein Objekt aus dem Array
        NSString * voiceIdentifier;
        voiceIdentifier = [voices objectAtIndex:i];
        
        // Den Namen (voiceName) eines 
        // voiceIdentifier ermitteln.
        NSString *voiceName =
        [[NSSpeechSynthesizer attributesForVoice:
          voiceIdentifier] valueForKey:NSVoiceName];
        
        // Den voiceIdentifiert dem NSPopUpButton hinzufügen
        [_voicesPopUpButton addItemWithTitle:voiceName];
    }
    
    int voiceIndex = 0;
    
    // Den ersten Eintrag im NSPopUpButton auswählen
    [_voicesPopUpButton selectItemAtIndex:voiceIndex];
    
    // Die Stimme an der gleichen Indexposition auswählen
    [speechSynth setVoice:
     [[NSSpeechSynthesizer availableVoices]
      objectAtIndex:voiceIndex]];
}


- (IBAction)speakButtonClicked:(id)sender
{
    // Die Zustände der Button umkehren
    _stopButton.enabled = YES;
    _speakButton.enabled = NO;
    
    // Den Text aus dem Textfeld in eine Variable holen
    NSString *input = _inputText.stringValue;
    
    // Den Text an den Sprachsynthesizer senden
    [speechSynth startSpeakingString:input];
}

- (IBAction)stopButtonClicked:(id)sender
{
    // Abbruch der Sprachausgabe
    [speechSynth stopSpeaking];
}

- (IBAction)voiceSelected:(id)sender
{
    // Die gewählte Position ermitteln.
    NSInteger index = _voicesPopUpButton.indexOfSelectedItem;
    
    // Die Stimme an der Indexposition auswählen
    [speechSynth setVoice:
     [[NSSpeechSynthesizer availableVoices]
      objectAtIndex:index]];
}

-(void)speechSynthesizer:
(NSSpeechSynthesizer *)sender 
       didFinishSpeaking:(BOOL)finishedSpeaking
{
    // Die Sprachausgabe wurde beendet.
    _stopButton.enabled = NO;
    _speakButton.enabled = YES;
}

-(BOOL)applicationShouldTerminateAfterLastWindowClosed:
(NSApplication *)sender
{
    return YES;
}

@end
