//
//  AppDelegate.m
//  Hallo Taxi
//
//  Created by Holger Hinzberg on 14.02.12.
//  Copyright (c) 2012 Cocoa-Coding. All rights reserved.
//

#import "AppDelegate.h"
#import "TaxiFareCalculator.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize sliderValueLabel = _sliderValueLabel;
@synthesize isHolidayTourCheckBox = _isHolidayTourCheckBox;
@synthesize isNightTourCheckBox = _isNightTourCheckBox;
@synthesize hasLuggageCheckBox = _hasLuggageCheckBox;
@synthesize taxiFareText = _taxiFareText;
@synthesize kilometerSlider = _kilometerSlider;

- (void)applicationDidFinishLaunching:
    (NSNotification *)aNotification
{
    fareCalculator = [TaxiFareCalculator new];
    fareCalculator.delegate = self;
    
    // Standardwerte setzen
    [self setFirstUserDefaults];
    
    [self loadUserDefaults];
}

- (void)awakeFromNib
{
    // Der Schieberegler ist bei Programmstart auf Position 1.
    // Das ist der Wert current im Interface Builder.
    _sliderValueLabel.intValue = 1;
    // Einen Fahrpreis gibt es noch nicht.
    _taxiFareText.stringValue = @"";
}

- (IBAction)sliderMoved:(id)sender
{
    // Ist der sender vom Type NSSlider?
    if ([sender isKindOfClass: [NSSlider class]])
    {
        NSSlider *slider = sender;
        int value = slider.intValue;
        _sliderValueLabel.intValue = value;
        fareCalculator.kilometer = value;
        
        // Rechnen
        [fareCalculator calculateFare];
    }
}

- (IBAction)checkBoxStateChanged:(id)sender
{
    // Hat schweres Gepäck?
    if ( _hasLuggageCheckBox.state == NSOnState)
    {
        fareCalculator.hasLuggage = YES;
    }
    else
    {
        fareCalculator.hasLuggage = NO;
    }
    
    // Ist es ein Feiertag?
    if ( _isHolidayTourCheckBox.state == NSOnState)
    {
        fareCalculator.isHolidayTour = YES;
    }
    else
    {
        fareCalculator.isHolidayTour = NO;
    }
    
    // Ist es eine Nachtfahrt?
    if ( _isNightTourCheckBox.state == NSOnState)
    {
        fareCalculator.isNightTour = YES;
    }
    else
    {
        fareCalculator.isNightTour = NO;
    }
    
    // Rechnen
    [fareCalculator calculateFare];
}

-(void)calculationDidFinish:(double)fare
{
    // Ergebnis an Label-Steuerelement übergeben.
    _taxiFareText.doubleValue = fare;
}

-(void)applicationWillTerminate:
(NSNotification *)notification
{
    // Die Standard-Einstellungen holen
    NSUserDefaults *defaults 
    = [NSUserDefaults standardUserDefaults];
    
    // Kilometer speichern
    [defaults setInteger:fareCalculator.kilometer
                  forKey:@"kilometer"];
    
    // Gepäck speichern
    [defaults setBool:fareCalculator.hasLuggage
               forKey:@"hasLuggage"];
    
    // Feiertag speichern
    [defaults setBool:fareCalculator.isHolidayTour
               forKey:@"isHolidayTour"];
    
    // Nachtfahrt speichern
    [defaults setBool:fareCalculator.isNightTour
               forKey:@"isNightTour"];
}

-(void)loadUserDefaults
{
    // Die Standard-Einstellungen holen
    NSUserDefaults *defaults 
    = [NSUserDefaults standardUserDefaults];
    
    // Die einzelnen Werte aus den
    // Benutzereinstellungen laden.
    
    // Kilometer laden
    // Das ist jetzt ein NSInteger
    NSInteger kilometer =
    [defaults integerForKey:@"kilometer"];
    
    // Gepäck laden
    BOOL hasLuggage =
    [defaults boolForKey:@"hasLuggage"];
    
    // Feiertag laden
    BOOL isHolidayTour =
    [defaults boolForKey:@"isHolidayTour"];
    
    // Nachtfahrt laden
    BOOL isNightTour =
    [defaults boolForKey:@"isNightTour"];
    
    // Die Werte den Kontrollkästchen und
    // dem Schieberegler zuweisen.
    
    // Kilometer für die Steuerelemente setzen
    _sliderValueLabel.intValue = kilometer;
    _kilometerSlider.intValue =kilometer;
    
    // Gepäck zuweisen
    if(hasLuggage == YES)
    {
        _hasLuggageCheckBox.state = NSOnState;
    }
    else
    {
        _hasLuggageCheckBox.state = NSOffState;

    }
    
    // Feiertag zuweisen
    if(isHolidayTour == YES)
    {
        _isHolidayTourCheckBox.state = NSOnState;
    }
    else
    {
        _isHolidayTourCheckBox.state = NSOffState;
    }
    
    // Nachtfahrt zuweisen
    if(isNightTour == YES)
    {
        _isNightTourCheckBox.state = NSOnState;
    }
    else
    {
        _isNightTourCheckBox.state = NSOffState;
    }
    
    // Die Einstellungen an den fareCalculator
    // übergeben und den Rechenvorgang starten.
    
    fareCalculator.kilometer = kilometer;
    fareCalculator.isNightTour = isNightTour;
    fareCalculator.isHolidayTour = isHolidayTour;
    fareCalculator.hasLuggage = hasLuggage;
    // rechnen starten
    [fareCalculator calculateFare];
}

-(void)setFirstUserDefaults
{
    // Ein Dictionary erzeugen ...
    NSMutableDictionary *defaultsDict =
    [NSMutableDictionary dictionary];
    
    // ... und mit den gleichen Objects und Keys füllen.  
    [defaultsDict setObject: 
     [NSNumber numberWithBool:YES] forKey:@"hasLuggage"];
    
    [defaultsDict setObject:
     [NSNumber numberWithBool:YES] forKey:@"isHolidayTour"];
    
    [defaultsDict setObject:
     [NSNumber numberWithBool:NO] forKey:@"isNightTour"];
    
    [defaultsDict setObject:
     [NSNumber numberWithInt:5] forKey:@"kilometer"];
    
    // Die Defaults laden
    NSUserDefaults *defaults 
    = [NSUserDefaults standardUserDefaults];
    
    // Das Dictionary als Standard setzen
    [defaults registerDefaults:defaultsDict];
}



@end
